apitest
=======

.. image:: https://travis-ci.org/BBVA/apitest.svg?branch=master
    :target: https://travis-ci.org/BBVA/apitest

.. image:: https://codecov.io/gh/BBVA/apitest/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/BBVA/apitest

*apitest: Testing your API for security*


.. image::  https://raw.githubusercontent.com/BBVA/apitest/master/doc/images/apitest-logo-128x128.png
    :height: 64px
    :width: 64px
    :alt: API Test logo

+----------------+--------------------------------------------+
|Current version | 1.0.0-alpha1                               |
+----------------+--------------------------------------------+
|Project site    | https://github.com/bbva/apitest            |
+----------------+--------------------------------------------+
|Issues          | https://github.com/bbva/apitest/issues/    |
+----------------+--------------------------------------------+
|Documentation   | https://apitest.readthedocs.org/           |
+----------------+--------------------------------------------+
|Authors         | Daniel Garcia (cr0hn)                      |
+----------------+--------------------------------------------+
|Latest Version  | 1.0.0                                      |
+----------------+--------------------------------------------+
|Python versions | 3.5 or above                               |
+----------------+--------------------------------------------+

What's apitest
==============

A Docker analysis tools

Very quick install
==================

**Install from Pypi**

.. code-block:: bash

    > python3.5 -m pip install apitest

**From source**

.. code-block:: bash

    > git clone https://github.com/bbva/apitest.git apitest
    > cd apitest
    > python3.5 setup.py install

Show options:

.. code-block:: bash

    > apitest -h

Documentation
=============

Go to documentation site: https://apitest.readthedocs.org/

Contributing
============

Any collaboration is welcome!

There're many tasks to do.You can check the `Issues <https://github.com/bbva/apitest/issues/>`_ and send us a Pull Request.

Also you can read the `TODO <https://github.com/bbva/apitest/blob/master/TODO.rst>`_ file.

License
=======

This project is distributed under `MIT license <https://github.com/bbva/apitest/blob/master/LICENSE>`_
